## New Naming Conventions in {{ site.forkawesome.minor_version }}

fa-[name]-[shape]-[o]-[direction]

A desire for better icon naming consistency and predictability are at the heart of the changes in naming conventions. Once you know the name of the base icon shape, you should be able to predict the names of variants.

#### fa-*

Solid icons as the base variant

- fa-bookmark
- fa-comment
- fa-folder

#### *-o

Outlined version of previous modifier

- fa-bookmark-o
- fa-comment-o
- fa-folder-o

#### *-circle

Circle under previous modifier

- fa-check-circle
- fa-exclamation-circle
- fa-plus-circle

#### *-square

Square under previous modifier

- fa-check-square
- fa-twitter-square
- fa-plus-square

#### *-right, *-up, etc.

Directional modifier always at the end

- fa-arrow-right
- fa-arrow-circle-right
- fa-angle-double-right

#### *-alt

Alternative to the original

- fa-unlock-alt
- fa-list-alt
- fa-github-alt

#### *-h, *-v

Horizontal & vertical modifiers

- fa-arrows-v
- fa-arrows-h
- fa-ellipsis-v

#### Combine 'em up&helip;

Consistent when strung together

- fa-arrow-circle-o-right
- fa-caret-square-o-right
- fa-hand-o-right